@@ -416,7 +416,8 @@ class Query(Table, Monad):
         # tricky part with dependent tables
         # if ifcond:
         
-        depts = res.dependents().filter(lambda x: x in res.getTables())
+        depts = res.dependents().filter(lambda x: x in res.getTables())\
+            .filter(lambda x: not self.joincond.children.filter(lambda y: y.iswhere and x in y.getTables()))
         if depts:
             notnullcond = depts.fmap(lambda x: Expr._notnull_(x.primaryExpr()))
             for key, expr in self.columns.items():
